bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOToGaussianGammaARD.add_plate_axis
======================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOToGaussianGammaARD.add_plate_axis